==> atlassian_connect_host-0.3.1.tar.gz: lib/src/host_registration_mongo_persistence.dart <==
library ac_dart.host_registration_mongo_persistence;

import 'package:atlassian_connect_host/host_registration_persistence.dart';
export 'package:atlassian_connect_host/host_registration_persistence.dart' show
    AcHostRegistrationRepository, Future, AcHostRegistration;

import 'package:mongo_dart/mongo_dart.dart';
export 'package:mongo_dart/mongo_dart.dart';

import 'package:option/option.dart';
export 'package:option/option.dart';

class AcHostRegistrationMongoRepository implements AcHostRegistrationRepository {

  final Db _db;
  final DbCollection _registrations;

  AcHostRegistrationMongoRepository(Db db, 
      [String collectionName = "acHostRegistrations"])
      : this._db = db,
        _registrations = db.collection(collectionName);


  @override
  Future<AcHostRegistration> create(AcHostRegistration hostRegistration) {
    print('create');
    return _db.open()
        .then((_) => _registrations.insert(hostRegistration.toJson()))
        .then((_) => hostRegistration);
    // TODO: what does mongo return here? Does it create an id that we 
    // should remember?
  }

  @override
  Future<Option<AcHostRegistration>> findRegistrationByHostKey(String hostKey) {
    return _db.open()
        .then((_) => _registrations.findOne(
            where.eq('hostDetails.key', hostKey)))
        .then((maybeNullMap) => new Option(maybeNullMap))
        .then((jsonMapOpt) => jsonMapOpt.map(
            (jsonMap) => new AcHostRegistration.fromJson(jsonMap)));
  }
}

AcHostRegistrationRepositoryFactory createMongoAcHostRegistrationRepository(String dbUrl) {
  return () => new AcHostRegistrationMongoRepository(new Db(dbUrl));
}

==> atlassian_connect_host-0.5.1.tar.gz: lib/src/host_registration_mongo_persistence.dart <==
library ac_dart.host_registration_mongo_persistence;

import 'package:atlassian_connect_host/host_registration_persistence.dart';
export 'package:atlassian_connect_host/host_registration_persistence.dart'
    show AcHostRegistrationRepository, Future, AcHostRegistration;

import 'package:mongo_dart/mongo_dart.dart';
export 'package:mongo_dart/mongo_dart.dart';

import 'package:option/option.dart';
export 'package:option/option.dart';

class AcHostRegistrationMongoRepository
    implements AcHostRegistrationRepository {
  final Db _db;
  final DbCollection _registrations;

  AcHostRegistrationMongoRepository(Db db,
      [String collectionName = "acHostRegistrations"])
      : this._db = db,
        _registrations = db.collection(collectionName);

  @override
  Future<AcHostRegistration> create(AcHostRegistration hostRegistration) {
    print('create');
    return _db
        .open()
        .then((_) => _registrations.insert(hostRegistration.toJson()))
        .then((_) => hostRegistration);
    // TODO: what does mongo return here? Does it create an id that we
    // should remember?
  }

  @override
  Future<Option<AcHostRegistration>> findRegistrationByHostKey(String hostKey) {
    return _db
        .open()
        .then(
            (_) => _registrations.findOne(where.eq('hostDetails.key', hostKey)))
        .then((maybeNullMap) => new Option(maybeNullMap))
        .then((jsonMapOpt) => jsonMapOpt
            .map((jsonMap) => new AcHostRegistration.fromJson(jsonMap)));
  }
}

AcHostRegistrationRepositoryFactory createMongoAcHostRegistrationRepository(
    String dbUrl) {
  return () => new AcHostRegistrationMongoRepository(new Db(dbUrl));
}
